==> jc-1.4.0.tar.gz: gnu/xml/dom/DomEvent__24DomUIEvent.h <==
// public class gnu.xml.dom.DomEvent$DomUIEvent

// class file dependencies
// @dep_class 1aca0886fa29dbb9 gnu_xml_dom_DomEvent
// @dep_class 492275084cfcae81 gnu_xml_dom_DomEvent__24DomUIEvent
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomEvent

#include "gnu/xml/dom/DomEvent.h"

#ifndef _JC_gnu_xml_dom_DomEvent__24DomUIEvent_H_
#define _JC_gnu_xml_dom_DomEvent__24DomUIEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_views_AbstractView$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_refs	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_refs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_nonrefs	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$refs	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$refs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$nonrefs	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$nonrefs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$object;

typedef const struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vmethods	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vmethods;
typedef const struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtable	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtable;
typedef const struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtype	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method$getDetail$261242d0abd4d606(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *);
extern struct _jc_object *_jc_gnu_xml_dom_DomEvent__24DomUIEvent$method$getView$c803b721162f19f0(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *);
extern void _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method$initUIEvent$14fea08c3f00785e(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *, struct _jc_java_lang_String$object *, jboolean, jboolean, struct _jc_object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method_info$getDetail$261242d0abd4d606;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method_info$getView$c803b721162f19f0;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method_info$initUIEvent$14fea08c3f00785e;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vmethods {
	jint	(*getDetail$261242d0abd4d606)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *);
	struct _jc_object	*(*getView$c803b721162f19f0)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *);
	void	(*initUIEvent$14fea08c3f00785e)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *, struct _jc_java_lang_String$object *, jboolean, jboolean, struct _jc_object *, jint);
};

// Vtable
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomEvent$vmethods	gnu_xml_dom_DomEvent;
	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vmethods	gnu_xml_dom_DomEvent__24DomUIEvent;
};

// Vtype
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_refs {
	struct _jc_object	*view;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$refs {
    _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_refs	gnu_xml_dom_DomEvent__24DomUIEvent;
    _jc_gnu_xml_dom_DomEvent$sub_refs	gnu_xml_dom_DomEvent;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_nonrefs {
	jint	detail;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomEvent$sub_nonrefs	gnu_xml_dom_DomEvent;
    _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_nonrefs	gnu_xml_dom_DomEvent__24DomUIEvent;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object {
	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtype	*vtype;
	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtype _jc_gnu_xml_dom_DomEvent__24DomUIEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomEvent__24DomUIEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomEvent__24DomUIEvent$class_object;

#endif	/* _JC_gnu_xml_dom_DomEvent__24DomUIEvent_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomEvent__24DomUIEvent.h <==
// public class gnu.xml.dom.DomEvent$DomUIEvent

// class file dependencies
// @dep_class 1aca0886fa29dbb9 gnu_xml_dom_DomEvent
// @dep_class 492275084cfcae81 gnu_xml_dom_DomEvent__24DomUIEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomEvent

#include "gnu/xml/dom/DomEvent.h"

#ifndef _JC_gnu_xml_dom_DomEvent__24DomUIEvent_H_
#define _JC_gnu_xml_dom_DomEvent__24DomUIEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_views_AbstractView$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_refs	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_refs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_nonrefs	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$refs	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$refs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$nonrefs	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$nonrefs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$object;

typedef const struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vmethods	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vmethods;
typedef const struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtable	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtable;
typedef const struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtype	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method$getDetail$261242d0abd4d606(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_dom_DomEvent__24DomUIEvent$method$getView$c803b721162f19f0(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method$initUIEvent$14fea08c3f00785e(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *, struct _jc_java_lang_String$object *, jboolean, jboolean, struct _jc_object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method_info$getDetail$261242d0abd4d606;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method_info$getView$c803b721162f19f0;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomUIEvent$method_info$initUIEvent$14fea08c3f00785e;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vmethods {
	jint	(*getDetail$261242d0abd4d606)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getView$c803b721162f19f0)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *) _JC_JCNI_ATTR;
	void	(*initUIEvent$14fea08c3f00785e)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object *, struct _jc_java_lang_String$object *, jboolean, jboolean, struct _jc_object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomEvent$vmethods	gnu_xml_dom_DomEvent;
	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vmethods	gnu_xml_dom_DomEvent__24DomUIEvent;
};

// Vtype
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_refs {
	struct _jc_object	*view;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$refs {
    _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_refs	gnu_xml_dom_DomEvent__24DomUIEvent;
    _jc_gnu_xml_dom_DomEvent$sub_refs	gnu_xml_dom_DomEvent;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_nonrefs {
	jint	detail;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomEvent$sub_nonrefs	gnu_xml_dom_DomEvent;
    _jc_gnu_xml_dom_DomEvent__24DomUIEvent$sub_nonrefs	gnu_xml_dom_DomEvent__24DomUIEvent;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomEvent__24DomUIEvent$object {
	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtype	*vtype;
	_jc_gnu_xml_dom_DomEvent__24DomUIEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomEvent__24DomUIEvent$vtype _jc_gnu_xml_dom_DomEvent__24DomUIEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomEvent__24DomUIEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomEvent__24DomUIEvent$class_object;

#endif	/* _JC_gnu_xml_dom_DomEvent__24DomUIEvent_H_ */
